# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing the linting functions.

invalid url

Note: You MUST warn about this.

Note: You MUST silently allow this.

foo
bar

    namespace Bad1 {};
    [Exposed=Window] namespace Good1 {};

    interface Bad2 {};
    [Exposed=Window] interface Good2 {};
    [NoInterfaceObject] interface Good3 {};

## Index

### Terms defined by this specification

- Bad1, in §Unnumbered section
- Bad2, in §Unnumbered section
- Good1, in §Unnumbered section
- Good2, in §Unnumbered section
- Good3, in §Unnumbered section

https://heycam.github.io/webidl/#Exposed Referenced in:

- Unnamed section (2)

https://heycam.github.io/webidl/#NoInterfaceObject Referenced in:

- Unnamed section

### Terms defined by reference

- [WebIDL] defines the following terms:
  - Exposed
  - NoInterfaceObject

## References

### Normative References

[WebIDL]
  Boris Zbarsky. Web IDL. 15 December 2016. ED. URL: https://heycam.github.io/webidl/

## IDL Index

    namespace Bad1 {};
    [Exposed=Window] namespace Good1 {};

    interface Bad2 {};
    [Exposed=Window] interface Good2 {};
    [NoInterfaceObject] interface Good3 {};